@@ -1,8 +1,8 @@
 ################################################################################
 #
-#  $Revision: 15 $
+#  $Revision: 16 $
 #  $Author: mhx $
-#  $Date: 2007/10/08 22:12:09 +0200 $
+#  $Date: 2007/10/14 05:15:26 +0200 $
 #
 ################################################################################
 #
@@ -21,7 +21,7 @@ use strict;
 use vars qw($VERSION);
 use Carp;
 
-$VERSION = do { my @r = '$Snapshot: /IPC-SysV/1.99_03 $' =~ /(\d+\.\d+(?:_\d+)?)/; @r ? $r[0] : '9.99' };
+$VERSION = do { my @r = '$Snapshot: /IPC-SysV/1.99_04 $' =~ /(\d+\.\d+(?:_\d+)?)/; @r ? $r[0] : '9.99' };
 $VERSION = eval $VERSION;
 
 # Figure out if we have support for native sized types
@@ -159,8 +159,8 @@ C<KEY> is equal to C<IPC_PRIVATE>
 
 =item *
 
-C<KEY> does not already  have  a  message queue
-associated with it, and C<I<FLAGS> & IPC_CREAT> is true.
+C<KEY> does not already have a message queue associated with
+it, and C<I<FLAGS> & IPC_CREAT> is true.
 
 =back
 
@@ -225,11 +225,11 @@ of these fields see you system documentation.
 
 =head1 SEE ALSO
 
-L<IPC::SysV> L<Class::Struct>
+L<IPC::SysV>, L<Class::Struct>
 
 =head1 AUTHORS
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr <gbarr@pobox.com>,
 Marcus Holland-Moritz <mhx@cpan.org>
 
 =head1 COPYRIGHT
